<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Addis_Ababa' => 'Oost-Afrikaanse tijd (Addis Abeba)',
        'Africa/Algiers' => 'Midden-Europese tijd (Algiers)',
        'Africa/Asmera' => 'Oost-Afrikaanse tijd (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Bangui' => 'West-Afrikaanse tijd (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Blantyre' => 'Centraal-Afrikaanse tijd (Blantyre)',
        'Africa/Brazzaville' => 'West-Afrikaanse tijd (Brazzaville)',
        'Africa/Bujumbura' => 'Centraal-Afrikaanse tijd (Bujumbura)',
        'Africa/Cairo' => 'Oost-Europese tijd (Caïro)',
        'Africa/Casablanca' => 'West-Europese tijd (Casablanca)',
        'Africa/Ceuta' => 'Midden-Europese tijd (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Dar_es_Salaam' => 'Oost-Afrikaanse tijd (Dar es Salaam)',
        'Africa/Djibouti' => 'Oost-Afrikaanse tijd (Djibouti)',
        'Africa/Douala' => 'West-Afrikaanse tijd (Douala)',
        'Africa/El_Aaiun' => 'West-Europese tijd (El Aaiun)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Gaborone' => 'Centraal-Afrikaanse tijd (Gaborone)',
        'Africa/Harare' => 'Centraal-Afrikaanse tijd (Harare)',
        'Africa/Johannesburg' => 'Zuid-Afrikaanse tijd (Johannesburg)',
        'Africa/Juba' => 'Centraal-Afrikaanse tijd (Juba)',
        'Africa/Kampala' => 'Oost-Afrikaanse tijd (Kampala)',
        'Africa/Khartoum' => 'Centraal-Afrikaanse tijd (Khartoem)',
        'Africa/Kigali' => 'Centraal-Afrikaanse tijd (Kigali)',
        'Africa/Kinshasa' => 'West-Afrikaanse tijd (Kinshasa)',
        'Africa/Lagos' => 'West-Afrikaanse tijd (Lagos)',
        'Africa/Libreville' => 'West-Afrikaanse tijd (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Luanda' => 'West-Afrikaanse tijd (Luanda)',
        'Africa/Lubumbashi' => 'Centraal-Afrikaanse tijd (Lubumbashi)',
        'Africa/Lusaka' => 'Centraal-Afrikaanse tijd (Lusaka)',
        'Africa/Malabo' => 'West-Afrikaanse tijd (Malabo)',
        'Africa/Maputo' => 'Centraal-Afrikaanse tijd (Maputo)',
        'Africa/Maseru' => 'Zuid-Afrikaanse tijd (Maseru)',
        'Africa/Mbabane' => 'Zuid-Afrikaanse tijd (Mbabane)',
        'Africa/Mogadishu' => 'Oost-Afrikaanse tijd (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nairobi' => 'Oost-Afrikaanse tijd (Nairobi)',
        'Africa/Ndjamena' => 'West-Afrikaanse tijd (Ndjamena)',
        'Africa/Niamey' => 'West-Afrikaanse tijd (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Porto-Novo' => 'West-Afrikaanse tijd (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (Sao Tomé)',
        'Africa/Tripoli' => 'Oost-Europese tijd (Tripoli)',
        'Africa/Tunis' => 'Midden-Europese tijd (Tunis)',
        'Africa/Windhoek' => 'Centraal-Afrikaanse tijd (Windhoek)',
        'America/Adak' => 'Hawaii-Aleoetische tijd (Adak)',
        'America/Anchorage' => 'Alaska-tijd (Anchorage)',
        'America/Anguilla' => 'Atlantic-tijd (Anguilla)',
        'America/Antigua' => 'Atlantic-tijd (Antigua)',
        'America/Araguaina' => 'Braziliaanse tijd (Araguaina)',
        'America/Argentina/La_Rioja' => 'Argentijnse tijd (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentijnse tijd (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentijnse tijd (Salta)',
        'America/Argentina/San_Juan' => 'Argentijnse tijd (San Juan)',
        'America/Argentina/San_Luis' => 'Argentijnse tijd (San Luis)',
        'America/Argentina/Tucuman' => 'Argentijnse tijd (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentijnse tijd (Ushuaia)',
        'America/Aruba' => 'Atlantic-tijd (Aruba)',
        'America/Asuncion' => 'Paraguayaanse tijd (Asunción)',
        'America/Bahia' => 'Braziliaanse tijd (Bahia)',
        'America/Bahia_Banderas' => 'Central-tijd (Bahía de Banderas)',
        'America/Barbados' => 'Atlantic-tijd (Barbados)',
        'America/Belem' => 'Braziliaanse tijd (Belém)',
        'America/Belize' => 'Central-tijd (Belize)',
        'America/Blanc-Sablon' => 'Atlantic-tijd (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazone-tijd (Boa Vista)',
        'America/Bogota' => 'Colombiaanse tijd (Bogota)',
        'America/Boise' => 'Mountain-tijd (Boise)',
        'America/Buenos_Aires' => 'Argentijnse tijd (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mountain-tijd (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazone-tijd (Campo Grande)',
        'America/Cancun' => 'Eastern-tijd (Cancun)',
        'America/Caracas' => 'Venezolaanse tijd (Caracas)',
        'America/Catamarca' => 'Argentijnse tijd (Catamarca)',
        'America/Cayenne' => 'Frans-Guyaanse tijd (Cayenne)',
        'America/Cayman' => 'Eastern-tijd (Cayman)',
        'America/Chicago' => 'Central-tijd (Chicago)',
        'America/Chihuahua' => 'Central-tijd (Chihuahua)',
        'America/Ciudad_Juarez' => 'Mountain-tijd (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Eastern-tijd (Atikokan)',
        'America/Cordoba' => 'Argentijnse tijd (Córdoba)',
        'America/Costa_Rica' => 'Central-tijd (Costa Rica)',
        'America/Creston' => 'Mountain-tijd (Creston)',
        'America/Cuiaba' => 'Amazone-tijd (Cuiabá)',
        'America/Curacao' => 'Atlantic-tijd (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (Danmarkshavn)',
        'America/Dawson' => 'Yukon-tijd (Dawson)',
        'America/Dawson_Creek' => 'Mountain-tijd (Dawson Creek)',
        'America/Denver' => 'Mountain-tijd (Denver)',
        'America/Detroit' => 'Eastern-tijd (Detroit)',
        'America/Dominica' => 'Atlantic-tijd (Dominica)',
        'America/Edmonton' => 'Mountain-tijd (Edmonton)',
        'America/Eirunepe' => 'Acre-tijd (Eirunepe)',
        'America/El_Salvador' => 'Central-tijd (El Salvador)',
        'America/Fort_Nelson' => 'Mountain-tijd (Fort Nelson)',
        'America/Fortaleza' => 'Braziliaanse tijd (Fortaleza)',
        'America/Glace_Bay' => 'Atlantic-tijd (Glace Bay)',
        'America/Godthab' => 'tijd in Groenland (Nuuk)',
        'America/Goose_Bay' => 'Atlantic-tijd (Goose Bay)',
        'America/Grand_Turk' => 'Eastern-tijd (Grand Turk)',
        'America/Grenada' => 'Atlantic-tijd (Grenada)',
        'America/Guadeloupe' => 'Atlantic-tijd (Guadeloupe)',
        'America/Guatemala' => 'Central-tijd (Guatemala)',
        'America/Guayaquil' => 'Ecuadoraanse tijd (Guayaquil)',
        'America/Guyana' => 'Guyaanse tijd (Guyana)',
        'America/Halifax' => 'Atlantic-tijd (Halifax)',
        'America/Havana' => 'Cubaanse tijd (Havana)',
        'America/Hermosillo' => 'Mexicaanse Pacific-tijd (Hermosillo)',
        'America/Indiana/Knox' => 'Central-tijd (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Eastern-tijd (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Eastern-tijd (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Central-tijd (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Eastern-tijd (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Eastern-tijd (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Eastern-tijd (Winamac, Indiana)',
        'America/Indianapolis' => 'Eastern-tijd (Indianapolis)',
        'America/Inuvik' => 'Mountain-tijd (Inuvik)',
        'America/Iqaluit' => 'Eastern-tijd (Iqaluit)',
        'America/Jamaica' => 'Eastern-tijd (Jamaica)',
        'America/Jujuy' => 'Argentijnse tijd (Jujuy)',
        'America/Juneau' => 'Alaska-tijd (Juneau)',
        'America/Kentucky/Monticello' => 'Eastern-tijd (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantic-tijd (Kralendijk)',
        'America/La_Paz' => 'Boliviaanse tijd (La Paz)',
        'America/Lima' => 'Peruaanse tijd (Lima)',
        'America/Los_Angeles' => 'Pacific-tijd (Los Angeles)',
        'America/Louisville' => 'Eastern-tijd (Louisville)',
        'America/Lower_Princes' => 'Atlantic-tijd (Beneden Prinsen Kwartier)',
        'America/Maceio' => 'Braziliaanse tijd (Maceió)',
        'America/Managua' => 'Central-tijd (Managua)',
        'America/Manaus' => 'Amazone-tijd (Manaus)',
        'America/Marigot' => 'Atlantic-tijd (Marigot)',
        'America/Martinique' => 'Atlantic-tijd (Martinique)',
        'America/Matamoros' => 'Central-tijd (Matamoros)',
        'America/Mazatlan' => 'Mexicaanse Pacific-tijd (Mazatlán)',
        'America/Mendoza' => 'Argentijnse tijd (Mendoza)',
        'America/Menominee' => 'Central-tijd (Menominee)',
        'America/Merida' => 'Central-tijd (Mérida)',
        'America/Metlakatla' => 'Alaska-tijd (Metlakatla)',
        'America/Mexico_City' => 'Central-tijd (Mexico-Stad)',
        'America/Miquelon' => 'Saint Pierre en Miquelon-tijd',
        'America/Moncton' => 'Atlantic-tijd (Moncton)',
        'America/Monterrey' => 'Central-tijd (Monterrey)',
        'America/Montevideo' => 'Uruguayaanse tijd (Montevideo)',
        'America/Montserrat' => 'Atlantic-tijd (Montserrat)',
        'America/Nassau' => 'Eastern-tijd (Nassau)',
        'America/New_York' => 'Eastern-tijd (New York)',
        'America/Nome' => 'Alaska-tijd (Nome)',
        'America/Noronha' => 'Fernando de Noronha-tijd',
        'America/North_Dakota/Beulah' => 'Central-tijd (Beulah, Noord-Dakota)',
        'America/North_Dakota/Center' => 'Central-tijd (Center, Noord-Dakota)',
        'America/North_Dakota/New_Salem' => 'Central-tijd (New Salem, Noord-Dakota)',
        'America/Ojinaga' => 'Central-tijd (Ojinaga)',
        'America/Panama' => 'Eastern-tijd (Panama)',
        'America/Paramaribo' => 'Surinaamse tijd (Paramaribo)',
        'America/Phoenix' => 'Mountain-tijd (Phoenix)',
        'America/Port-au-Prince' => 'Eastern-tijd (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantic-tijd (Port of Spain)',
        'America/Porto_Velho' => 'Amazone-tijd (Porto Velho)',
        'America/Puerto_Rico' => 'Atlantic-tijd (Puerto Rico)',
        'America/Punta_Arenas' => 'Chileense tijd (Punta Arenas)',
        'America/Rankin_Inlet' => 'Central-tijd (Rankin Inlet)',
        'America/Recife' => 'Braziliaanse tijd (Recife)',
        'America/Regina' => 'Central-tijd (Regina)',
        'America/Resolute' => 'Central-tijd (Resolute)',
        'America/Rio_Branco' => 'Acre-tijd (Rio Branco)',
        'America/Santarem' => 'Braziliaanse tijd (Santarem)',
        'America/Santiago' => 'Chileense tijd (Santiago)',
        'America/Santo_Domingo' => 'Atlantic-tijd (Santo Domingo)',
        'America/Sao_Paulo' => 'Braziliaanse tijd (São Paulo)',
        'America/Scoresbysund' => 'tijd in Groenland (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska-tijd (Sitka)',
        'America/St_Barthelemy' => 'Atlantic-tijd (Saint-Barthélemy)',
        'America/St_Johns' => 'Newfoundland-tijd (Saint John’s)',
        'America/St_Kitts' => 'Atlantic-tijd (Saint Kitts)',
        'America/St_Lucia' => 'Atlantic-tijd (Saint Lucia)',
        'America/St_Thomas' => 'Atlantic-tijd (Saint Thomas)',
        'America/St_Vincent' => 'Atlantic-tijd (Saint Vincent)',
        'America/Swift_Current' => 'Central-tijd (Swift Current)',
        'America/Tegucigalpa' => 'Central-tijd (Tegucigalpa)',
        'America/Thule' => 'Atlantic-tijd (Thule)',
        'America/Tijuana' => 'Pacific-tijd (Tijuana)',
        'America/Toronto' => 'Eastern-tijd (Toronto)',
        'America/Tortola' => 'Atlantic-tijd (Tortola)',
        'America/Vancouver' => 'Pacific-tijd (Vancouver)',
        'America/Whitehorse' => 'Yukon-tijd (Whitehorse)',
        'America/Winnipeg' => 'Central-tijd (Winnipeg)',
        'America/Yakutat' => 'Alaska-tijd (Yakutat)',
        'Antarctica/Casey' => 'West-Australische tijd (Casey)',
        'Antarctica/Davis' => 'Davis-tijd',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville-tijd',
        'Antarctica/Macquarie' => 'Oost-Australische tijd (Macquarie)',
        'Antarctica/Mawson' => 'Mawson-tijd',
        'Antarctica/McMurdo' => 'Nieuw-Zeelandse tijd (McMurdo)',
        'Antarctica/Palmer' => 'Chileense tijd (Palmer)',
        'Antarctica/Rothera' => 'Rothera-tijd',
        'Antarctica/Syowa' => 'Syowa-tijd',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
        'Antarctica/Vostok' => 'Vostok-tijd',
        'Arctic/Longyearbyen' => 'Midden-Europese tijd (Longyearbyen)',
        'Asia/Aden' => 'Arabische tijd (Aden)',
        'Asia/Almaty' => 'West-Kazachse tijd (Alma-Ata)',
        'Asia/Amman' => 'Oost-Europese tijd (Amman)',
        'Asia/Anadyr' => 'Anadyr-tijd',
        'Asia/Aqtau' => 'West-Kazachse tijd (Aqtau)',
        'Asia/Aqtobe' => 'West-Kazachse tijd (Aqtöbe)',
        'Asia/Ashgabat' => 'Turkmeense tijd (Asjchabad)',
        'Asia/Atyrau' => 'West-Kazachse tijd (Atıraw)',
        'Asia/Baghdad' => 'Arabische tijd (Bagdad)',
        'Asia/Bahrain' => 'Arabische tijd (Bahrein)',
        'Asia/Baku' => 'Azerbeidzjaanse tijd (Bakoe)',
        'Asia/Bangkok' => 'Indochinese tijd (Bangkok)',
        'Asia/Barnaul' => 'tijd in Rusland (Barnaul)',
        'Asia/Beirut' => 'Oost-Europese tijd (Beiroet)',
        'Asia/Bishkek' => 'Kirgizische tijd (Bisjkek)',
        'Asia/Brunei' => 'Bruneise tijd',
        'Asia/Calcutta' => 'Indiase tijd (Calcutta)',
        'Asia/Chita' => 'Jakoetsk-tijd (Chita)',
        'Asia/Choibalsan' => 'Ulaanbaatar-tijd (Tsjojbalsan)',
        'Asia/Colombo' => 'Indiase tijd (Colombo)',
        'Asia/Damascus' => 'Oost-Europese tijd (Damascus)',
        'Asia/Dhaka' => 'Bengalese tijd (Dhaka)',
        'Asia/Dili' => 'Oost-Timorese tijd (Dili)',
        'Asia/Dubai' => 'Golf-standaardtijd (Dubai)',
        'Asia/Dushanbe' => 'Tadzjiekse tijd (Doesjanbe)',
        'Asia/Famagusta' => 'Oost-Europese tijd (Famagusta)',
        'Asia/Gaza' => 'Oost-Europese tijd (Gaza)',
        'Asia/Hebron' => 'Oost-Europese tijd (Hebron)',
        'Asia/Hong_Kong' => 'Hongkongse tijd',
        'Asia/Hovd' => 'Hovd-tijd',
        'Asia/Irkutsk' => 'Irkoetsk-tijd',
        'Asia/Jakarta' => 'West-Indonesische tijd (Jakarta)',
        'Asia/Jayapura' => 'Oost-Indonesische tijd (Jayapura)',
        'Asia/Jerusalem' => 'Israëlische tijd (Jeruzalem)',
        'Asia/Kabul' => 'Afghaanse tijd (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamtsjatski-tijd (Kamtsjatka)',
        'Asia/Karachi' => 'Pakistaanse tijd (Karachi)',
        'Asia/Katmandu' => 'Nepalese tijd (Kathmandu)',
        'Asia/Khandyga' => 'Jakoetsk-tijd (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsk-tijd',
        'Asia/Kuala_Lumpur' => 'Maleisische tijd (Kuala Lumpur)',
        'Asia/Kuching' => 'Maleisische tijd (Kuching)',
        'Asia/Kuwait' => 'Arabische tijd (Koeweit)',
        'Asia/Macau' => 'Chinese tijd (Macau)',
        'Asia/Magadan' => 'Magadan-tijd',
        'Asia/Makassar' => 'Centraal-Indonesische tijd (Makassar)',
        'Asia/Manila' => 'Filipijnse tijd (Manilla)',
        'Asia/Muscat' => 'Golf-standaardtijd (Muscat)',
        'Asia/Nicosia' => 'Oost-Europese tijd (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnojarsk-tijd (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Novosibirsk-tijd',
        'Asia/Omsk' => 'Omsk-tijd',
        'Asia/Oral' => 'West-Kazachse tijd (Oral)',
        'Asia/Phnom_Penh' => 'Indochinese tijd (Phnom Penh)',
        'Asia/Pontianak' => 'West-Indonesische tijd (Pontianak)',
        'Asia/Pyongyang' => 'Koreaanse tijd (Pyongyang)',
        'Asia/Qatar' => 'Arabische tijd (Qatar)',
        'Asia/Qostanay' => 'West-Kazachse tijd (Qostanay)',
        'Asia/Qyzylorda' => 'West-Kazachse tijd (Qyzylorda)',
        'Asia/Rangoon' => 'Myanmarese tijd (Rangoon)',
        'Asia/Riyadh' => 'Arabische tijd (Riyad)',
        'Asia/Saigon' => 'Indochinese tijd (Ho Chi Minhstad)',
        'Asia/Sakhalin' => 'Sachalin-tijd',
        'Asia/Samarkand' => 'Oezbeekse tijd (Samarkand)',
        'Asia/Seoul' => 'Koreaanse tijd (Seoul)',
        'Asia/Shanghai' => 'Chinese tijd (Sjanghai)',
        'Asia/Singapore' => 'Singaporese standaardtijd',
        'Asia/Srednekolymsk' => 'Magadan-tijd (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei-tijd',
        'Asia/Tashkent' => 'Oezbeekse tijd (Tasjkent)',
        'Asia/Tbilisi' => 'Georgische tijd (Tbilisi)',
        'Asia/Tehran' => 'Iraanse tijd (Teheran)',
        'Asia/Thimphu' => 'Bhutaanse tijd (Thimphu)',
        'Asia/Tokyo' => 'Japanse tijd (Tokio)',
        'Asia/Tomsk' => 'tijd in Rusland (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatar-tijd',
        'Asia/Urumqi' => 'tijd in China (Urumqi)',
        'Asia/Ust-Nera' => 'Vladivostok-tijd (Ust-Nera)',
        'Asia/Vientiane' => 'Indochinese tijd (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostok-tijd',
        'Asia/Yakutsk' => 'Jakoetsk-tijd',
        'Asia/Yekaterinburg' => 'Jekaterinenburg-tijd',
        'Asia/Yerevan' => 'Armeense tijd (Jerevan)',
        'Atlantic/Azores' => 'Azoren-tijd',
        'Atlantic/Bermuda' => 'Atlantic-tijd (Bermuda)',
        'Atlantic/Canary' => 'West-Europese tijd (Canarische Eilanden)',
        'Atlantic/Cape_Verde' => 'Kaapverdische tijd (Kaapverdië)',
        'Atlantic/Faeroe' => 'West-Europese tijd (Faeröer)',
        'Atlantic/Madeira' => 'West-Europese tijd (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
        'Atlantic/South_Georgia' => 'Zuid-Georgische tijd (Zuid-Georgia)',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (Sint-Helena)',
        'Atlantic/Stanley' => 'Falklandeilandse tijd (Stanley)',
        'Australia/Adelaide' => 'Midden-Australische tijd (Adelaide)',
        'Australia/Brisbane' => 'Oost-Australische tijd (Brisbane)',
        'Australia/Broken_Hill' => 'Midden-Australische tijd (Broken Hill)',
        'Australia/Darwin' => 'Midden-Australische tijd (Darwin)',
        'Australia/Eucla' => 'Midden-Australische westelijke tijd (Eucla)',
        'Australia/Hobart' => 'Oost-Australische tijd (Hobart)',
        'Australia/Lindeman' => 'Oost-Australische tijd (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe-eilandse tijd',
        'Australia/Melbourne' => 'Oost-Australische tijd (Melbourne)',
        'Australia/Perth' => 'West-Australische tijd (Perth)',
        'Australia/Sydney' => 'Oost-Australische tijd (Sydney)',
        'CST6CDT' => 'Central-tijd',
        'EST5EDT' => 'Eastern-tijd',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Etc/UTC' => 'gecoördineerde wereldtijd',
        'Europe/Amsterdam' => 'Midden-Europese tijd (Amsterdam)',
        'Europe/Andorra' => 'Midden-Europese tijd (Andorra)',
        'Europe/Astrakhan' => 'Moskou-tijd (Astrakhan)',
        'Europe/Athens' => 'Oost-Europese tijd (Athene)',
        'Europe/Belgrade' => 'Midden-Europese tijd (Belgrado)',
        'Europe/Berlin' => 'Midden-Europese tijd (Berlijn)',
        'Europe/Bratislava' => 'Midden-Europese tijd (Bratislava)',
        'Europe/Brussels' => 'Midden-Europese tijd (Brussel)',
        'Europe/Bucharest' => 'Oost-Europese tijd (Boekarest)',
        'Europe/Budapest' => 'Midden-Europese tijd (Boedapest)',
        'Europe/Busingen' => 'Midden-Europese tijd (Busingen)',
        'Europe/Chisinau' => 'Oost-Europese tijd (Chisinau)',
        'Europe/Copenhagen' => 'Midden-Europese tijd (Kopenhagen)',
        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
        'Europe/Gibraltar' => 'Midden-Europese tijd (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
        'Europe/Helsinki' => 'Oost-Europese tijd (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
        'Europe/Istanbul' => 'tijd in Turkije (Istanboel)',
        'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
        'Europe/Kaliningrad' => 'Oost-Europese tijd (Kaliningrad)',
        'Europe/Kiev' => 'Oost-Europese tijd (Kiev)',
        'Europe/Kirov' => 'tijd in Rusland (Kirov)',
        'Europe/Lisbon' => 'West-Europese tijd (Lissabon)',
        'Europe/Ljubljana' => 'Midden-Europese tijd (Ljubljana)',
        'Europe/London' => 'Greenwich Mean Time (Londen)',
        'Europe/Luxembourg' => 'Midden-Europese tijd (Luxemburg)',
        'Europe/Madrid' => 'Midden-Europese tijd (Madrid)',
        'Europe/Malta' => 'Midden-Europese tijd (Malta)',
        'Europe/Mariehamn' => 'Oost-Europese tijd (Mariehamn)',
        'Europe/Minsk' => 'Moskou-tijd (Minsk)',
        'Europe/Monaco' => 'Midden-Europese tijd (Monaco)',
        'Europe/Moscow' => 'Moskou-tijd',
        'Europe/Oslo' => 'Midden-Europese tijd (Oslo)',
        'Europe/Paris' => 'Midden-Europese tijd (Parijs)',
        'Europe/Podgorica' => 'Midden-Europese tijd (Podgorica)',
        'Europe/Prague' => 'Midden-Europese tijd (Praag)',
        'Europe/Riga' => 'Oost-Europese tijd (Riga)',
        'Europe/Rome' => 'Midden-Europese tijd (Rome)',
        'Europe/Samara' => 'Samara-tijd',
        'Europe/San_Marino' => 'Midden-Europese tijd (San Marino)',
        'Europe/Sarajevo' => 'Midden-Europese tijd (Sarajevo)',
        'Europe/Saratov' => 'Moskou-tijd (Saratov)',
        'Europe/Simferopol' => 'Moskou-tijd (Simferopol)',
        'Europe/Skopje' => 'Midden-Europese tijd (Skopje)',
        'Europe/Sofia' => 'Oost-Europese tijd (Sofia)',
        'Europe/Stockholm' => 'Midden-Europese tijd (Stockholm)',
        'Europe/Tallinn' => 'Oost-Europese tijd (Tallinn)',
        'Europe/Tirane' => 'Midden-Europese tijd (Tirana)',
        'Europe/Ulyanovsk' => 'Moskou-tijd (Ulyanovsk)',
        'Europe/Vaduz' => 'Midden-Europese tijd (Vaduz)',
        'Europe/Vatican' => 'Midden-Europese tijd (Vaticaanstad)',
        'Europe/Vienna' => 'Midden-Europese tijd (Wenen)',
        'Europe/Vilnius' => 'Oost-Europese tijd (Vilnius)',
        'Europe/Volgograd' => 'Wolgograd-tijd',
        'Europe/Warsaw' => 'Midden-Europese tijd (Warschau)',
        'Europe/Zagreb' => 'Midden-Europese tijd (Zagreb)',
        'Europe/Zurich' => 'Midden-Europese tijd (Zürich)',
        'Indian/Antananarivo' => 'Oost-Afrikaanse tijd (Antananarivo)',
        'Indian/Chagos' => 'Indische Oceaan-tijd (Chagosarchipel)',
        'Indian/Christmas' => 'Christmaseilandse tijd',
        'Indian/Cocos' => 'Cocoseilandse tijd (Cocoseilanden)',
        'Indian/Comoro' => 'Oost-Afrikaanse tijd (Comoro)',
        'Indian/Kerguelen' => 'Franse zuidelijke en Antarctische tijd (Kerguelen)',
        'Indian/Mahe' => 'Seychelse tijd (Mahé)',
        'Indian/Maldives' => 'Maldivische tijd (Maldiven)',
        'Indian/Mauritius' => 'Mauritiaanse tijd (Mauritius)',
        'Indian/Mayotte' => 'Oost-Afrikaanse tijd (Mayotte)',
        'Indian/Reunion' => 'Réunionse tijd',
        'MST7MDT' => 'Mountain-tijd',
        'PST8PDT' => 'Pacific-tijd',
        'Pacific/Apia' => 'Apia-tijd',
        'Pacific/Auckland' => 'Nieuw-Zeelandse tijd (Auckland)',
        'Pacific/Bougainville' => 'Papoea-Nieuw-Guineese tijd (Bougainville)',
        'Pacific/Chatham' => 'Chatham-tijd',
        'Pacific/Easter' => 'Paaseilandse tijd',
        'Pacific/Efate' => 'Vanuatuaanse tijd (Efate)',
        'Pacific/Enderbury' => 'Phoenixeilandse tijd (Enderbury)',
        'Pacific/Fakaofo' => 'Tokelau-eilandse tijd (Fakaofo)',
        'Pacific/Fiji' => 'Fijische tijd',
        'Pacific/Funafuti' => 'Tuvaluaanse tijd (Funafuti)',
        'Pacific/Galapagos' => 'Galapagoseilandse tijd',
        'Pacific/Gambier' => 'Gambiereilandse tijd (Îles Gambier)',
        'Pacific/Guadalcanal' => 'Salomonseilandse tijd (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro-tijd (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleoetische tijd (Honolulu)',
        'Pacific/Kiritimati' => 'Line-eilandse tijd (Kiritimati)',
        'Pacific/Kosrae' => 'Kosraese tijd',
        'Pacific/Kwajalein' => 'Marshalleilandse tijd (Kwajalein)',
        'Pacific/Majuro' => 'Marshalleilandse tijd (Majuro)',
        'Pacific/Marquesas' => 'Marquesaseilandse tijd (Marquesaseilanden)',
        'Pacific/Midway' => 'Samoaanse tijd (Midway)',
        'Pacific/Nauru' => 'Nauruaanse tijd',
        'Pacific/Niue' => 'Niuese tijd',
        'Pacific/Norfolk' => 'Norfolkeilandse tijd',
        'Pacific/Noumea' => 'Nieuw-Caledonische tijd (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoaanse tijd (Pago Pago)',
        'Pacific/Palau' => 'Belause tijd (Palau)',
        'Pacific/Pitcairn' => 'Pitcairneilandse tijd',
        'Pacific/Ponape' => 'Pohnpei-tijd',
        'Pacific/Port_Moresby' => 'Papoea-Nieuw-Guineese tijd (Port Moresby)',
        'Pacific/Rarotonga' => 'Cookeilandse tijd (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro-tijd (Saipan)',
        'Pacific/Tahiti' => 'Tahitiaanse tijd',
        'Pacific/Tarawa' => 'Gilberteilandse tijd (Tarawa)',
        'Pacific/Tongatapu' => 'Tongaanse tijd (Tongatapu)',
        'Pacific/Truk' => 'Chuukse tijd',
        'Pacific/Wake' => 'Wake-eilandse tijd',
        'Pacific/Wallis' => 'Wallis en Futunase tijd',
    ],
    'Meta' => [],
];
